set mem 500m
cd /Users/Ivan/Dropbox/ivanf/ExtrapoLATE/Data
set more 1
#delimit ;


* Empirical Example for "Extrapolating: External Validity and Overidentification in a LATE Framework," by J. Angrist and I. Fernandez-Val ;

capture log close;
log using /Users/Ivan/Dropbox/ivanf/ExtrapoLATE/Results/prog0.log, replace;

use m_d_806, clear;

* Construct twin instrument;
gen byte multi2nd = 0;
replace multi2nd = 1 if (ageq2nd == ageq3rd);


* Check illegitimate kids;
gen byte  illegit=0;
* if qtrmar>0 then do;
*    qtrmar=qtrmar-1;
*    if qtrbthm<=qtrmar then yom=yobm+agemar;
*    else if qtrbthm>qtrmar then yom=yobm+agemar+1;
*    dom_q = yom+(qtrmar/4);
*    do1b_q = yobk+((qtrbkid)/4);
*    if (dom_q-do1b_q)>0 then illegit=1;
* end;

gen qtrmar1 = qtrmar-1 if (qtrmar > 0);
gen yom = yobm + agemar if (qtrmar > 0);
replace yom = yobm+agemar+1 if (qtrbthm>qtrmar1 & qtrmar>0);
gen dom_q = yom+(qtrmar1/4) if (qtrmar > 0);
gen do1b_q = yobk+((qtrbkid)/4) if (qtrmar > 0);
replace illegit = 1  if ((dom_q-do1b_q)>0 & (qtrmar > 0));


* construct the sexes of 1st two kids;
gen byte boy1st = sexk==0;
gen byte boy2nd = sex2nd==0;
gen byte boys2  = (sexk==0) & (sex2nd==0);
gen byte girls2 = (sexk==1) & (sex2nd==1);
gen byte samesex = (boys2==1) | (girls2==1);
gen byte morekids = kidcount>2;

label var boy1st "first birth boy";
label var samesex "first two kids are of same sex";
label var morekids "had more than 2 kids";
label var boys2 "first two births boys";
label var girls2 "first two births girls";

* construct race indicators for mom and dad;
gen byte blackm = racem==2;
gen byte hispm = racem==12;
gen byte whitem = racem==1;
gen byte othracem = 1 - blackm - hispm - whitem;

gen byte blackd = raced==2;
gen byte hispd = raced==12;
gen byte whited = raced==1;
gen byte othraced = 1-blackd-hispd-whited;

label var blackm "=1 if black";
label var hispm "=1 if hispanic";
label var othracem "=1 if other race (white is ref)";
label var blackd "=1 if black";
label var hispd "=1 if hispanic";
label var othraced "=1 if other race (white is ref)";

* educ stuff;

gen byte educm = gradem-3;
replace educm = gradem-2 if (fingradm == 2 | fingradm==1);
replace educm = (educm >= 0)*educm;
label var educm "moms educ";

gen byte hsgrad =(educm==12);
gen byte hsormore =(educm>=12);
gen byte moreths =(educm>12);

* get ages of mom and dad;
* plus ages when 1st kid was born;

gen int agem1 = agem*1;
gen int aged1 = aged*1;
label var agem1 "age in years of mom";
label var aged1 "age in years of dad";

gen int yobd = 79-aged;
replace yobd = 80-aged if (qtrbthd==0);

gen int ageqm = 4*(80-yobm)-qtrbthm-1;
gen int ageqd = 4*(80-yobd)-qtrbthd;
gen int agefstm = int((ageqm-ageqk)/4);
gen int agefstd = int((ageqd-ageqk)/4);
label var agefstd "age of dad when kid first born";
label var agefstm "age of mom when kid first born";

gen int age2ndm=int((ageqm-ageq2nd)/4);

* calculate mom and dad labor supply variables;

gen int weeksm1=weeksm*1;
gen weeksd1=weeksd*1;

gen byte workedm=weeksm>0;
gen byte workedd=weeksd>0;
replace workedd = . if weeksd == .;

gen int hourswd=hoursd*1;
gen int hourswm=hoursm*1;

gen incomed=income1d+max(0,income2d);
gen incomem=income1m+max(0,income2m);
** deflate wages **;
replace incomem=incomem*2.099173554;
replace incomed=incomed*2.099173554;

gen faminc1=faminc*1;
replace faminc1=faminc1*2.099173554;
gen famincl=log(max(faminc1,1));
gen nonmomi=faminc1-income1m*2.099173554;;
gen nonmomil=log(max(1,nonmomi));

label var weeksm1 "weeks worked mom";
label var workedm "mom worked last year";
label var weeksd1 "weeks worked dad";
label var workedd "dad worked last year";
label var famincl "log family income";
label var agefstm "age of mom at first birth";
label var nonmomi "income not generated by mom";
label var incomed "dads labor income";
label var incomem "moms labor income";
label var faminc1 "family income";
label var hourswd "hours of work per week, dad";
label var hourswm "hours of work per week, mom";

*** compute age-corrected effects *****
 1. approx age of 3rd
 2. compute corrected morekids;

label var ageq2nd "age of second kid in qtrs";
label var ageqk "age of first kid in qtrs";
label var ageq3rd "age of 3rd kid in qtrs";
label var age2ndm "mom age 2nd birth - yrs"; 


* if morekids=0 then ageq3rdk=0;

gen int morea3=morekids*ageq3rd;

gen int qobm=qtrbthm*1;
gen byte const=1;
gen msample=0;
replace msample = 1 if ((aged != .) &  (timesmar==1) &  (marital==0) &  (illegit==0) &  (agefstd >= 15) &  (agefstm >= 15)); 

keep kidcount morekids boys2 girls2 boy1st samesex multi2nd agem agem1 agefstm
blackm hispm othracem workedm weeksm1 hourswm incomem faminc1 nonmomi
famincl nonmomil aged1 agefstd moreths boy2nd msample 
educm moreths hsormore hsgrad asex aage aqtrbrth asex2nd aage2nd
blackd hispd othraced workedd weeksd1 hourswd incomed marital
ageq2nd ageqk ageq3rd morea3 ageqm yobm qobm const age2ndm ;

global fsample "agem1 >= 21 & agem1<=35 & kidcount>=2 & ageq2nd>4 & agefstm>=15 &  asex==0 & aage==0 & aqtrbrth==0 &  asex2nd==0 & aage2nd==0 & aqtrbrth==0";

global msample "agem1 >= 21 & agem1<=35 & kidcount>=2 & ageq2nd>4 & agefstm>=15 &  asex==0 & aage==0 & aqtrbrth==0 &  asex2nd==0 & aage2nd==0 & aqtrbrth==0 & msample == 1";

gen int edgroup = (educm<12) + 2*(educm==12) + 3*(educm> 12 & educm<=15) + 4*(educm>15);
gen int age2grp = (ageq2nd<=16) + 2*(ageq2nd>16 & ageq2nd<=32) + 3*(ageq2nd>32);
replace age2grp = . if ageq2nd == .;
gen int agemgrp = (age2ndm<=21) + 2*(age2ndm>21 & age2ndm<=23) + 3*(age2ndm>23 & age2ndm<=25) + 4*(age2ndm>25);
replace agemgrp = . if age2ndm == .;


sum kidcount morekids boy1st boy2nd boys2 girls2 samesex multi2nd agem1 aged1 agefstm ageqk ageq2nd agefstd workedm workedd weeksm1 weeksd1 hourswm hourswd incomem incomed faminc1 nonmomi if $fsample;

sum  kidcount morekids boy1st boy2nd boys2 girls2 samesex multi2nd agem1 aged1 agefstm ageqk ageq2nd agefstd workedm workedd weeksm1 weeksd1 hourswm hourswd incomem incomed faminc1 nonmomi if $msample;

table age2grp edgroup if $msample;

keep if $fsample;
keep workedm weeksm1 morekids samesex multi2nd age2grp edgroup msample;

rename weeksm1 y1;
rename workedm y2;
rename morekids x;
rename samesex z1;
rename multi2nd z2;
rename age2grp g1;
rename edgroup g2;

gen g = 10*g1 + g2;
tabulate g, gen(gi);

sum;

sort g;

saveold fulldata, replace;


** end data steps **;

clear;

log close;
